#
# spec file for package webvfx
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name mlt
%define mltversion 6.6.0
%define sover 1
%define mltmaj %(echo %{mltversion} |cut -d "." -f 1)
# Find qt version used to build
%define qt5version %(pkg-config --modversion Qt5Core)
%define _rev    e918ce4667e623c3d60735cb898223e730c6d7af
Name:           webvfx
Version:        0.44+git20160823
Release:        lp150.3.1
Summary:        Video effects engine based on web technologies
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            https://github.com/mltframework/webvfx
Source0:        %{_name}-%{mltversion}.tar.gz
# This is needed by shotcut and will only build within the mlt sources.
Source1:        https://github.com/mltframework/webvfx/archive/%{_rev}.tar.gz#/webvfx-%{version}.tar.gz
# PATCH-FIX-OPENSUSE libmlt-0.8.2-vdpau.patch reddwarf@opensuse.org -- Make VDPAU support work without the devel package
Patch1:         libmlt-0.8.2-vdpau.patch
#PATCH-FIX-UPSTREAM webvfx-versioned-libdir.patch davejplater@gmail.com -- install webvfx lib in versioned _libdir
Patch10:        webvfx-versioned-libdir.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(mlt++)
BuildRequires:  pkgconfig(mlt-framework)
#Requires:

%description
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML.

%package -n libwebvfx%{sover}
Summary:        Video effects engine based on web technologies
Group:          System/Libraries

%description -n libwebvfx%{sover}
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML.

%package devel
Summary:        Video effects engine based on web technologies
Group:          Development/Libraries/C and C++
Requires:       libwebvfx%{sover} = %{version}
Requires:       pkgconfig(mlt-framework) = %{mltversion}

%description devel
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML. This package contains
the development library link.

%package module
Summary:        Webvfx module for MLT
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description module
A module plugin for the MLT multimedia framework.

%package -n qmelt
Summary:        A Melt that works with webvfx
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description -n qmelt
MLT is a multimedia framework, designed and developed for television
broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of
applications. The functionality of the system is provided via an
assortment of tools, XML authoring components, and an plug-in based API.

%prep
%setup -q -n %{_name}-%{mltversion} -a 1
%patch1
%patch10

%build
pushd webvfx-%{_rev}
%qmake5 \
	QMAKE_STRIP="" \
	MLT_SOURCE="%{_builddir}/%{_name}-%{mltversion}/" \
	WLIB=%{_lib} \
        PREFIX="%{_prefix}" -Wall -recursive

make %{?_smp_mflags} VERBOSE=1
popd

%install
pushd webvfx-%{_rev}
%qmake5_install
chmod 0644 LICENSE README.md
popd
#Add webvfx module to versioned mlt module directory
mv %{buildroot}%{_libdir}/mlt %{buildroot}%{_libdir}/mlt-%{mltmaj}
chmod 0755 %{buildroot}%{_bindir}/*
#Create man pages for executables.
mkdir -p %{buildroot}%{_mandir}/man1
pushd %{buildroot}%{_bindir}
for i in *; do
	help2man -N --no-discard-stderr -h "-help" -v "-version" ./${i} -o %{buildroot}%{_mandir}/man1/${i}.1 || touch %{buildroot}%{_mandir}/man1/${i}.1
done
popd

%post -n libwebvfx%{sover} -p /sbin/ldconfig
%postun -n libwebvfx%{sover} -p /sbin/ldconfig

%files
%{_bindir}/webvfx*
%{_mandir}/man1/webvfx*
%license webvfx-%{_rev}/LICENSE
%doc webvfx-%{_rev}/README.md

%files module
%defattr(0755, root, root, 0755)
%{_libdir}/mlt-%{mltmaj}/

%files -n libwebvfx%{sover}
%defattr(0755, root, root, 0755)
%{_libdir}/libwebvfx.so.*

%files devel
%defattr(0755, root, root, 0755)
%{_libdir}/libwebvfx.so

%files -n qmelt
%{_bindir}/qmelt
%{_mandir}/man1/qmelt*

%changelog
* Sun Mar 11 2018 davejplater@gmail.com
- Fix Leap:15.0 build and run spec-cleaner.
* Wed Jan 24 2018 davejplater@gmail.com
- Removed mlt patches:
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch,
  libmlt-nomorexlocale_h.patch, em_close.patch and
  use-recommended-freetype-include.patch.
- Package LICENSE and README.md.
* Fri Aug 25 2017 davejplater@gmail.com
- Apply all mlt patches before building.
* Thu Jul  6 2017 jengelh@inai.de
- Trim filler wording from descriptions; fix identical
  descriptions being used in different subpackages.
- Cure "useless use of cat" (`ls -1`) by replacing with just *.
* Sun Jun 11 2017 davejplater@gmail.com
- Added man pages for binaries.
* Thu Jun  8 2017 davejplater@gmail.com
- Created initial package version 0.44+git20160823 from current
  git rev: e918ce4667e623c3d60735cb898223e730c6d7af needed by
  shotcut. See boo#1043070
- Added webvfx-versioned-libdir.patch to enable arch dependent
  library directory install
